summaryrefslogtreecommitdiffstats
path: root/tqtinterface/qt4/src/styles/tqwindowsstyle.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'tqtinterface/qt4/src/styles/tqwindowsstyle.cpp')
-rw-r--r--tqtinterface/qt4/src/styles/tqwindowsstyle.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/tqtinterface/qt4/src/styles/tqwindowsstyle.cpp b/tqtinterface/qt4/src/styles/tqwindowsstyle.cpp
index 5a25f3d..7588997 100644
--- a/tqtinterface/qt4/src/styles/tqwindowsstyle.cpp
+++ b/tqtinterface/qt4/src/styles/tqwindowsstyle.cpp
@@ -98,7 +98,7 @@ class FriendlyMenuData : public TQMenuData
class TQWindowsStyle::Private : public TQObject
{
public:
- Private(TQWindowsStyle *tqparent);
+ Private(TQWindowsStyle *parent);
bool hasSeenAlt(const TQWidget *widget) const;
bool altDown() const { return alt_down; }
@@ -112,12 +112,12 @@ private:
int menuBarTimer;
};
-TQWindowsStyle::Private::Private(TQWindowsStyle *tqparent)
-: TQObject(tqparent, "TQWindowsStylePrivate"), alt_down(FALSE), menuBarTimer(0)
+TQWindowsStyle::Private::Private(TQWindowsStyle *parent)
+: TQObject(parent, "TQWindowsStylePrivate"), alt_down(FALSE), menuBarTimer(0)
{
}
// Returns true if the toplevel tqparent of \a widget has seen the Alt-key
bool TQWindowsStyle::Private::hasSeenAlt(const TQWidget *widget) const
{
widget = widget->tqtopLevelWidget();
@@ -112,12 +112,12 @@ private:
{
}
-// Returns true if the toplevel tqparent of \a widget has seen the Alt-key
+// Returns true if the toplevel parent of \a widget has seen the Alt-key
bool TQWindowsStyle::Private::hasSeenAlt(const TQWidget *widget) const
{